==> jc-1.4.0.tar.gz: gnu/java/security/x509/Util.h <==
// public final class gnu.java.security.x509.Util

// class file dependencies
// @dep_class 70edc74efc8796dc gnu_java_security_x509_Util
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_x509_Util_H_
#define _JC_gnu_java_security_x509_Util_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_Util$sub_refs	_jc_gnu_java_security_x509_Util$sub_refs;
typedef struct _jc_gnu_java_security_x509_Util$sub_nonrefs	_jc_gnu_java_security_x509_Util$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_Util$refs	_jc_gnu_java_security_x509_Util$refs;
typedef struct _jc_gnu_java_security_x509_Util$nonrefs	_jc_gnu_java_security_x509_Util$nonrefs;
typedef struct _jc_gnu_java_security_x509_Util$object	_jc_gnu_java_security_x509_Util$object;

typedef struct _jc_gnu_java_security_x509_Util$fields_struct	_jc_gnu_java_security_x509_Util$fields_struct;
typedef const struct _jc_gnu_java_security_x509_Util$vmethods	_jc_gnu_java_security_x509_Util$vmethods;
typedef const struct _jc_gnu_java_security_x509_Util$vtable	_jc_gnu_java_security_x509_Util$vtable;
typedef const struct _jc_gnu_java_security_x509_Util$vtype	_jc_gnu_java_security_x509_Util$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_Util$fields_struct {
	struct _jc_java_lang_String$object	*HEX;
};
extern _jc_gnu_java_security_x509_Util$fields_struct _jc_gnu_java_security_x509_Util$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_Util$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_x509_Util$object *);

// Static methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$formatInt$c7eadd687e225269(_jc_env *, jint, jint, jint);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$hexDump$b0dd77499e8b0197(_jc_env *, struct _jc_byte_array *, jint, jint, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$hexDump$07ea22745c8673eb(_jc_env *, struct _jc_byte_array *, struct _jc_java_lang_String$object *);
extern _jc_byte_array *_jc_gnu_java_security_x509_Util$method$toByteArray$613c1bd3234e2aa3(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$toHexString$ebe51b0de61921a2(_jc_env *, struct _jc_byte_array *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$toHexString$1a11a62bf4f44189(_jc_env *, struct _jc_byte_array *, jchar);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$toHexString$ce4def168ae3f4af(_jc_env *, struct _jc_byte_array *, jint, jint);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$toHexString$39631018c0686ff1(_jc_env *, struct _jc_byte_array *, jint, jint, jchar);

// Virtual methods structure
struct _jc_gnu_java_security_x509_Util$vmethods {
};

// Vtable
struct _jc_gnu_java_security_x509_Util$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_Util$vmethods	gnu_java_security_x509_Util;
};

// Vtype
struct _jc_gnu_java_security_x509_Util$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_Util$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_Util$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_Util$refs {
    _jc_gnu_java_security_x509_Util$sub_refs	gnu_java_security_x509_Util;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_Util$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_Util$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_Util$sub_nonrefs	gnu_java_security_x509_Util;
};

// Object instance structure
struct _jc_gnu_java_security_x509_Util$object {
	_jc_gnu_java_security_x509_Util$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_Util$vtype	*vtype;
	_jc_gnu_java_security_x509_Util$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_Util$vtype _jc_gnu_java_security_x509_Util$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_Util, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_Util$class_object;

#endif	/* _JC_gnu_java_security_x509_Util_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/Util.h <==
// public final class gnu.java.security.x509.Util

// class file dependencies
// @dep_class 70edc74efc8796dc gnu_java_security_x509_Util
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_x509_Util_H_
#define _JC_gnu_java_security_x509_Util_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_Util$sub_refs	_jc_gnu_java_security_x509_Util$sub_refs;
typedef struct _jc_gnu_java_security_x509_Util$sub_nonrefs	_jc_gnu_java_security_x509_Util$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_Util$refs	_jc_gnu_java_security_x509_Util$refs;
typedef struct _jc_gnu_java_security_x509_Util$nonrefs	_jc_gnu_java_security_x509_Util$nonrefs;
typedef struct _jc_gnu_java_security_x509_Util$object	_jc_gnu_java_security_x509_Util$object;

typedef struct _jc_gnu_java_security_x509_Util$fields_struct	_jc_gnu_java_security_x509_Util$fields_struct;
typedef const struct _jc_gnu_java_security_x509_Util$vmethods	_jc_gnu_java_security_x509_Util$vmethods;
typedef const struct _jc_gnu_java_security_x509_Util$vtable	_jc_gnu_java_security_x509_Util$vtable;
typedef const struct _jc_gnu_java_security_x509_Util$vtype	_jc_gnu_java_security_x509_Util$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_Util$fields_struct {
	struct _jc_java_lang_String$object	*HEX;
};
extern _jc_gnu_java_security_x509_Util$fields_struct _jc_gnu_java_security_x509_Util$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_Util$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_x509_Util$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$formatInt$c7eadd687e225269(_jc_env *, jint, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$hexDump$b0dd77499e8b0197(_jc_env *, struct _jc_byte_array *, jint, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$hexDump$07ea22745c8673eb(_jc_env *, struct _jc_byte_array *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_security_x509_Util$method$toByteArray$613c1bd3234e2aa3(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$toHexString$ebe51b0de61921a2(_jc_env *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$toHexString$1a11a62bf4f44189(_jc_env *, struct _jc_byte_array *, jchar) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$toHexString$ce4def168ae3f4af(_jc_env *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_Util$method$toHexString$39631018c0686ff1(_jc_env *, struct _jc_byte_array *, jint, jint, jchar) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_Util$vmethods {
};

// Vtable
struct _jc_gnu_java_security_x509_Util$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_Util$vmethods	gnu_java_security_x509_Util;
};

// Vtype
struct _jc_gnu_java_security_x509_Util$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_Util$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_Util$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_Util$refs {
    _jc_gnu_java_security_x509_Util$sub_refs	gnu_java_security_x509_Util;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_Util$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_Util$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_Util$sub_nonrefs	gnu_java_security_x509_Util;
};

// Object instance structure
struct _jc_gnu_java_security_x509_Util$object {
	_jc_gnu_java_security_x509_Util$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_Util$vtype	*vtype;
	_jc_gnu_java_security_x509_Util$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_Util$vtype _jc_gnu_java_security_x509_Util$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_Util, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_Util$class_object;

#endif	/* _JC_gnu_java_security_x509_Util_H_ */
